#' tableau de synthèse des données en cumul annuel
#'
#' @param data Le dataframe.
#' @param type_logement Collectifs ou individuels.
#' @param type_zone Liste des types de zonage à intégrer dans la facette.
#' @return Un table kable
#' @importFrom dplyr filter mutate pull select full_join arrange
#' @importFrom kableExtra kable_styling row_spec add_header_above add_indent
#' @importFrom knitr kable
#' @importFrom stringr str_split_fixed
#' @importFrom tidyr spread
#' @export
creer_tableau_synthese_annuel <- function(data = indic_ecln,
                                          type_zone = c("France", "R\u00e9gions", "D\u00e9partements"),
                                          type_logement = "collectif") {
  indic <- c(
    "Encours - Appartements",
    "Mises en vente - Appartements",
    "Ventes - Appartements",
    "PrixM2 - Appartements"
  )
  if (type_logement == "individuel") {
    indic <- c(
      "Encours - Maisons",
      "Mises en vente - Maisons",
      "Ventes - Maisons",
      "PrixPar - Maisons"
    )
  }
  input <- indic_ecln %>%
    dplyr::filter(
      .data$Indicateur %in% indic,
      .data$TypeZone %in% type_zone,
      .data$TypeIndicateur == "Cumul annuel",
      .data$Periode == max(.data$Periode)
    ) %>%
    dplyr::mutate(Indicateur = stringr::str_split_fixed(.data$Indicateur, "-", 2)[, 1])

  nombre_zone <- length(unique(input$CodeZone))
  nombre_fr_dep_reg <- 1 + length(unique(input %>% dplyr::filter(.data$TypeZone %in% c("France", "R\u00e9gions", "D\u00e9partements")) %>% dplyr::pull(.data$CodeZone)))
  res <- input %>%
    dplyr::select(.data$TypeZone, .data$Zone, .data$Indicateur, .data$Valeur) %>%
    tidyr::spread(.data$Indicateur, .data$Valeur) %>%
    dplyr::full_join(
      input %>%
        dplyr::select(.data$TypeZone, .data$Zone, .data$Indicateur, .data$TauxEvolution12Mois) %>%
        tidyr::spread(.data$Indicateur, .data$TauxEvolution12Mois),
      by = c("TypeZone", "Zone")
    ) %>%
    dplyr::arrange(.data$Zone) %>%
    dplyr::select(2, 6, 10, 4, 8, 3, 7, 5, 9) %>%
    knitr::kable("html",
      col.names = c(
        "Zone", "Sur les 12 derniers mois", "Evolution sur un an (en %)",
        "Sur les 12 derniers mois", "Evolution sur un an (en %)",
        "En fin de p\u00e9riode", "Evolution sur un an (en %)",
        "Prix moyen sur les 12 derniers mois (en \u20ac)", "Evolution sur un an (en %)"
      ),
      digits = c(0, 0, 1, 0, 1, 0, 1, 0, 1),
      format.args = list(big.mark = " ", decimal.mark = ",")
    ) %>%
    kableExtra::kable_styling(font_size = 12) %>%
    kableExtra::row_spec(1:2, bold = T, background = "#f0f0f5") %>%
    kableExtra::add_header_above(c(" " = 1, "Ventes" = 2, "Mises en vente" = 2, "Encours" = 2, "Prix au m2" = 2)) %>%
    kableExtra::add_indent(c(3:nombre_zone))
  if ("ABC" %in% type_zone) {
    res <- res %>%
      kableExtra::row_spec(nombre_fr_dep_reg:nombre_zone, bold = T, background = "#bebece")
  }
  return(res)
}
