
library(magrittr)
library(haven)
library(readxl)
library(lubridate)
library(COGiter)
library(purrr)
library(dplyr)
library(tidyr)
library(forcats)
library(lubridate)
library(stringr)
library(dtplyr)
options(scipen = 999)

# Recherche du dernier millesime disponible
fichiers <- list.files("X:/SCTE/DEP/Donnees_confidentielles/Conjoncture/ECLN/Publication"
,include.dirs = FALSE,full.names = FALSE, pattern = "stat_info")
# fichiers <- list.files('data-raw',include.dirs = FALSE,full.names = FALSE, pattern = "stat_info")
millesime <- fichiers %>%
  substr(26,31) %>%
  max()
# fichier_donnees <- paste0("data-raw/stat_info_data_regionaux_",millesime,".csv")
# fichier_calage <- paste0("data-raw/cale_ventile_",millesime,".xls")
fichier_donnees <- paste0("X:/SCTE/DEP/Donnees_confidentielles/Conjoncture/ECLN/Publication/stat_info_data_regionaux_",millesime,"_.csv")
fichier_calage <- paste0("X:/SCTE/DEP/Donnees_confidentielles/Conjoncture/ECLN/Publication/cale_ventile_",millesime,".xls")

# 1. Récupération des données
# ------------------------------------------------------------------------------------------------------
# Données envoyées par mail ou déposées sur le serveur RStudio (/home/partage-ECLN/ECLN/AAAATN/) sont déposées dans le répertoire des données confidentielles avec accès restreint

# Données ECLN brutes non secrétisées - Attention séparateur ; et décimal .
ECLN <- read.csv2(fichier_donnees, header = T, sep = ";", dec = ".")

# Fichier de calage des ventes ventilés au niveau dep et reg - Seules les ventes du dernier trimestre sont calées
cale_reg_dep <- read_excel(fichier_calage)


# 2. Construction de la table des indicateurs communaux par type de logement et nature du projet
# Dans le projet initial, seuls les indicateurs par type de logement étaient construits
# Pour pouvoir utiliser, la nouvelle variable construction sur existant, on construit à l'identique des indicateurs sur la distinction de la nature du projet
# La table finale sera une juxtaposition des indicateurs par type de logement et par nature du projet

# 2.1 Construction de la table des indicateurs par type de logement id_type_lgt (1=individuel/2=collectif)
# ---------------------------------------------------------------------------------------------------------------------------------------------------
# On calcule par communes (code_insee-> DEPCOM), trimestre de mises en vente (trim_mev->Periode) et type de logement (id_type_lgt), le nombre de mises en vente (mev_t)
# On calcule par communes (code_insee-> DEPCOM), trimestres (trimestre_enquete -> periode) et type de logement (id_type_lgt) :
# - nombre de ventes en investissement locatif ( nb_lgt_inv = nb_lgt_inv_t1 + nb_lgt_inv_t2 + nb_lgt_inv_t3 + nb_lgt_inv_t4 + nb_lgt_inv_t5 + nb_lgt_inv_t6)
# - nombre de ventes hors investissement locatif (nb_hors_resa_inv = nb_resa - nb_lgt_inv)
# - nombre de logements réservés à la vente (nb_resa)
# - prix total des ventes (prix)
# - Surface totale (surface)
# - encours de logements proposés à la vente (stock_fin)
# On passe au format long et on renomme les indicateurs en les suffisant avec le type de logement

indic_typ <- ECLN %>%
  select(DEPCOM = code_insee, Periode = trim_mev, id_type_lgt, mev_t) %>%
  as_tibble() %>%
  filter(Periode >= 201701) %>%
  group_by(id_type_lgt, DEPCOM, Periode) %>%
  summarise(mev_t = sum(mev_t, na.rm = T)) %>%
  ungroup() %>%
  full_join ( ECLN %>%
    select(DEPCOM = code_insee, Periode = trimestre_enquete , id_type_lgt, nb_resa, nb_lgt_inv_t1, nb_lgt_inv_t2, nb_lgt_inv_t3, nb_lgt_inv_t4, nb_lgt_inv_t5, nb_lgt_inv_t6,
            surface, prix,
           stock_fin ) %>%
    filter(Periode >= 201701) %>%
    mutate(
      nb_lgt_inv = nb_lgt_inv_t1 + nb_lgt_inv_t2 + nb_lgt_inv_t3 + nb_lgt_inv_t4 + nb_lgt_inv_t5 + nb_lgt_inv_t6,
      nb_hors_resa_inv = nb_resa - nb_lgt_inv
    ) %>%
    group_by(id_type_lgt, DEPCOM, Periode) %>%
    summarise(
      nb_resa = sum(nb_resa, na.rm = T),
      nb_resa_inv = sum(nb_lgt_inv, na.rm = T),
      nb_hors_resa_inv = sum(nb_hors_resa_inv, na.rm = T),
      stock_fin = sum(stock_fin, na.rm = T),
      prix = sum(prix, na.rm = T),
     surface = sum(surface, na.rm = T)
    ) %>%
    ungroup()) %>%
  gather(Indicateur, Valeur, mev_t:surface) %>%
  mutate(
    Periode = factor(Periode),
    id_type_lgt = factor(id_type_lgt),
    DEPCOM = factor(DEPCOM),
    id_type_lgt = fct_recode(id_type_lgt, Maisons = "1", Appartements = "2"),
    Indicateur = fct_recode(factor(Indicateur), `Mises en vente` = "mev_t", Ventes = "nb_resa", `Ventes en investissement locatif` = "nb_resa_inv", `Ventes hors investissement locatif` = "nb_hors_resa_inv", Encours = "stock_fin", Prix = "prix", Surface = "surface"),
    Indicateur = str_c(Indicateur, " - ", id_type_lgt)
  ) %>%
  select(-id_type_lgt) %>%
  mutate(Valeur = ifelse(is.na(Valeur), 0, Valeur))



# 2.2 Construction de la table des indicateurs par type de construction id_nature_projet (1=construction neuve/2=construction sur existant)
# ------------------------------------------------------------------------------------------------------------------------------------------------------
# On calcule par communes (code_insee-> DEPCOM), trimestre de mises en vente (trim_mev->Periode) et type de construction (id_nature_projet), le nombre de mises en vente (mev_t)
# On calcule par communes (code_insee-> DEPCOM), trimestres (trimestre_enquete -> periode) et type de construction (id_nature_projet) :
# - nombre de ventes en investissement locatif ( nb_lgt_inv = nb_lgt_inv_t1 + nb_lgt_inv_t2 + nb_lgt_inv_t3 + nb_lgt_inv_t4 + nb_lgt_inv_t5 + nb_lgt_inv_t6)
# - nombre de ventes hors investissement locatif (nb_hors_resa_inv = nb_resa - nb_lgt_inv)
# - nombre de logements réservés à la vente (nb_resa)
# - prix total des ventes (prix)
# - Surface totale (surface)
# - encours de logements proposés à la vente (stock_fin)
# On passe au format long et on renomme les indicateurs en les suffisant avec le type de construction

indic_cons <- ECLN %>%
  select(DEPCOM = code_insee, Periode = trim_mev, id_nature_projet, mev_t) %>%
  as_tibble() %>%
  filter(Periode >= 201701) %>%
  group_by(id_nature_projet, DEPCOM, Periode) %>%
  summarise(mev_t = sum(mev_t, na.rm = T)) %>%
  ungroup() %>%
  full_join ( ECLN %>%
                select(DEPCOM = code_insee, Periode = trimestre_enquete , id_nature_projet, nb_resa, nb_lgt_inv_t1, nb_lgt_inv_t2, nb_lgt_inv_t3, nb_lgt_inv_t4, nb_lgt_inv_t5, nb_lgt_inv_t6,
                       surface, prix,
                       stock_fin ) %>%
                filter(Periode >= 201701) %>%
                mutate(
                  nb_lgt_inv = nb_lgt_inv_t1 + nb_lgt_inv_t2 + nb_lgt_inv_t3 + nb_lgt_inv_t4 + nb_lgt_inv_t5 + nb_lgt_inv_t6,
                  nb_hors_resa_inv = nb_resa - nb_lgt_inv
                ) %>%
                group_by(id_nature_projet, DEPCOM, Periode) %>%
                summarise(
                  nb_resa = sum(nb_resa, na.rm = T),
                  nb_resa_inv = sum(nb_lgt_inv, na.rm = T),
                  nb_hors_resa_inv = sum(nb_hors_resa_inv, na.rm = T),
                  stock_fin = sum(stock_fin, na.rm = T),
                  prix = sum(prix, na.rm = T),
                  surface = sum(surface, na.rm = T)
                ) %>%
                ungroup()) %>%
  gather(Indicateur, Valeur, mev_t:surface) %>%
  mutate(
    Periode = factor(Periode),
    id_nature_projet = factor(id_nature_projet),
    DEPCOM = factor(DEPCOM),
    id_nature_projet = fct_recode(id_nature_projet,`Constructions neuves` = "1", `Constructions sur existant` = "2"),
    Indicateur = fct_recode(factor(Indicateur), `Mises en vente` = "mev_t", Ventes = "nb_resa", `Ventes en investissement locatif` = "nb_resa_inv", `Ventes hors investissement locatif` = "nb_hors_resa_inv", Encours = "stock_fin", Prix = "prix", Surface = "surface"),
    Indicateur = str_c(Indicateur, " - ", id_nature_projet)
  ) %>%
  select(- id_nature_projet) %>%
  mutate(Valeur = ifelse(is.na(Valeur), 0, Valeur))


# Cogification des deux tables
# -----------------------------------------------------------------------------
# on passe la table au cog à jour
# on rajoute les communes non comprises dans la table de départ (jointure à droite) avec des valeurs manquantes pour les périodes,indicateurs et valeurs non présentes dans la talbe de départ.
# Cela va permettre de faire des agrégations par EPCI, Dep, REG
# Puis on complète avec des valeurs à null pour toutes les combinaisons possibles pour le triplet : depcom, périodes, indicateurs
# On recogifie cette fois et on enlève les DOM


indic_typ <- passer_au_cog_a_jour(indic_typ, code_commune = DEPCOM, aggrege = T, garder = F) %>%
  right_join(communes %>% select(DEPCOM)) %>%
  complete(DEPCOM, Periode, Indicateur,
           fill = list(Valeur = 0)
  ) %>%
  filter(!is.na(Indicateur), !is.na(Periode)) %>%
  passer_au_cog_a_jour(code_commune = DEPCOM, aggrege = T, garder_info_supra = T) %>%
  select(REG, DEPCOM, Periode, Indicateur, Valeur) %>%
  filter(!(REG %in% c("01", "02", "03", "04", "05", "06"))) %>%
  mutate_if(is.character, as.factor)


indic_cons <- passer_au_cog_a_jour(indic_cons, code_commune = DEPCOM, aggrege = T, garder_info_supra = FALSE) %>%
  right_join(communes %>% select(DEPCOM)) %>%
  complete(DEPCOM, Periode, Indicateur,
           fill = list(Valeur = 0)
  ) %>%
  filter(!is.na(Indicateur), !is.na(Periode)) %>%
  passer_au_cog_a_jour(code_commune = DEPCOM, aggrege = T, garder_info_supra = T) %>%
  select(REG, DEPCOM, Periode, Indicateur, Valeur) %>%
  filter(!(REG %in% c("01", "02", "03", "04", "05", "06"))) %>%
  mutate_if(is.character, as.factor)


# 3.2 Calcul sur total logements et agrégation des deux tables d'indicateurs
# Dans la table des indicateurs ventilés par type de logement, les indicateurs sont décomposés par type de logement (Appartements et Maisons).
# Il faut donc calculer le total (appartements + maisons). Il suffit de le faire sur une table car le total sera le même si on ventile par nature du projet.
# Cette opération doit se faire sur une table au cog à jour.
# Le calcul du total ne se fait que sur une des deux tables

indic_typ <- bind_rows(
  indic_typ,
  indic_typ %>%
    mutate(Indicateur = str_split_fixed(Indicateur, " - ", 2)[, 1] %>% str_c(" - Logements") %>% as.factor()) %>%
    group_by_if(is.factor) %>%
    summarise_all(funs(sum(., na.rm = T))) %>%
    ungroup()
) %>%
  mutate_if(is.character, as.factor)


# 3.3 Cogification = Aggrégation de l'ensemble des calculs sur les zones géo (EPCI, REG, FRANCE métro)
# On empile les deux tables et on cogifie
# On enlève le zonage communes qui ne nous servira plus pour les travaux suivants :
# - le calage
# - le calcul des indicateurs annuels trimestriels et glissants


indic_ecln <- bind_rows (indic_typ, indic_cons)

indic_ecln_cog <- indic_ecln %>%
  select(-REG) %>%
  group_split(Periode) %>%
  furrr::future_map_dfr(cogifier)

# Table sans les communes pour alléger les travaux suivants :
# - le calage
# - le calcul des indicateurs annuels trimestriels et glissants

indic_ecln_ss_com <- indic_ecln_cog %>%
arrange(TypeZone, Zone, CodeZone, Indicateur, Periode) %>%
  filter(TypeZone != "Communes")

# 4. Calage
# Les Mises en ventes et le stock en fin de trimestre (= Encours) sont calées pour les données du dernier trimestre
# La cale est actuellement uniquement calculées au niveau régional et départemental
# De fait, pour les mises en ventes et les encours, les données à l'EPCI ne seront pas diffusées sur le dernier truimestre mais sur le précédant
# On récupère la cale dans le fichier cale_reg_dep : elle est décomposée par type delogement (id_type_lgt), de construction (id_nature_projet) et type de pièces (typo)
# L'objectif est de calculer pour chaque indicateur devant être calé sa cale pour les différents niveaux géographiquex (france, reg et dep) :
#   - Mises en ventes - Maisons
# - Mises en ventes - Appartements
# - Mises en ventes - Logements
# - Mises en ventes - Construction neuve
# - Mises en ventes - Construction sur existant
# - Encours - Maisons
# - Encours - Appartements
# - Encours - Logements
# - Encours - Construction neuve
# - Encours - Construction sur existant

# 4.1 Calage des indicateurs ventilés par type de logement
# # On transpose (lignes (modalités de typo) en colonnes) la table de calage pour pouvoir sommer
# # la cale (=valeurs de chaque typo) par type de logement
# # on conserve tous les échelons géo pour pouvoir calculer les différents agrégats (nat, reg, dep)

Cale_typ <- cale_reg_dep %>%
  filter(!(reg2 %in% c("01", "02", "03", "04", "05", "06"))) %>%
  select (reg2, dep, id_type_lgt, typo, Periode = trimestre_enquete, cale) %>%
  group_by(Periode, reg2, dep, id_type_lgt, typo) %>%
  summarise(cale_tot = sum(cale), na.rm = T) %>%
  pivot_wider(id_cols =c(Periode, reg2, dep, id_type_lgt),
              names_from = typo,
              values_from = cale_tot) %>%
  mutate(Cale = t1 + t2 + t3 + t4 + t5 + t6,
         Periode = factor(Periode),
         id_type_lgt = factor(id_type_lgt),
         Calage = fct_recode(id_type_lgt,`Cale - Maisons` = "1", `Cale - Appartements` = "2")) %>%
  ungroup() %>%
  select(-id_type_lgt, -c(t1:t6))

Cale_typ_nat <- Cale_typ %>%
  group_by (Periode, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate(TypeZone = "France",
         TypeZone = factor(TypeZone),
         Periode = factor(Periode),
         CodeZone = "FRMETRO",
         CodeZone = factor(CodeZone))


Cale_typ_reg <- Cale_typ %>%
  group_by (Periode,reg2, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate( TypeZone = "Régions",
          TypeZone = factor(TypeZone),
          Periode = factor(Periode),
          CodeZone = factor(reg2)) %>%
  ungroup() %>%
  select(-reg2)

Cale_typ_dep <- Cale_typ %>%
  group_by (Periode,dep, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate( TypeZone = "Départements",
          TypeZone = factor(TypeZone),
          Periode = factor(Periode),
          CodeZone = factor(dep)) %>%
  ungroup() %>%
  select(-dep)


# On empile les tables cela nous permettra de calculer le total
Cale_typ <- bind_rows (Cale_typ_nat, Cale_typ_reg, Cale_typ_dep)

#  On calcule le total pour tout type de logement

Cale_typ_tot <- bind_rows(
  Cale_typ,
  Cale_typ %>%
    mutate(Calage = str_split_fixed(Calage, " - ", 2)[, 1] %>% str_c(" - Logements") %>% as.factor()) %>%
    group_by_if (is.factor) %>%
    summarise_all(funs(sum(., na.rm = T))) %>%
    ungroup()
) %>%
  mutate_if(is.character, as.factor)

# 4.2 Calage pour les indicateurs ventilés par nature du projet
# On transpose (lignes (modalités de typo) en colonnes) la table de calage pour pouvoir sommer
# la cale (=valeurs de chaque typo) par nature du projet
# on conserve tous les échelons géo pour pouvoir calculer les différents agrégats

Cale_cons <- cale_reg_dep %>%
  filter(!(reg2 %in% c("01", "02", "03", "04", "05", "06"))) %>%
  select (reg2, dep, id_nature_projet, typo, Periode = trimestre_enquete, cale) %>%
  group_by(Periode, reg2, dep, id_nature_projet, typo) %>%
  summarise(cale_tot = sum(cale), na.rm = T) %>%
  pivot_wider(id_cols =c(Periode, reg2, dep, id_nature_projet),
              names_from = typo,
              values_from = cale_tot) %>%
  mutate(Cale = t1 + t2 + t3 + t4 + t5 + t6,
         Periode = factor(Periode),
         id_nature_projet = factor(id_nature_projet),
         Calage = fct_recode(id_nature_projet,`Cale - Constructions neuves` = "1", `Cale - Constructions sur existant` = "2")) %>%
  ungroup() %>%
  select(-id_nature_projet,-c(t1:t6))


Cale_cons_nat <- Cale_cons %>%
  group_by (Periode, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate(TypeZone = "France",
         TypeZone = factor(TypeZone),
         Periode = factor(Periode),
         CodeZone = "FRMETRO",
         CodeZone = factor(CodeZone))


Cale_cons_reg <- Cale_cons %>%
  group_by (Periode,reg2, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate( TypeZone = "Régions",
          TypeZone = factor(TypeZone),
          Periode = factor(Periode),
          CodeZone = factor(reg2)) %>%
  ungroup() %>%
  select(-reg2)

Cale_cons_dep <- Cale_cons %>%
  group_by (Periode,dep, Calage) %>%
  summarise(Cale= sum(Cale)) %>%
  mutate( TypeZone = "Départements",
          TypeZone = factor(TypeZone),
          Periode = factor(Periode),
          CodeZone = factor(dep))%>%
  ungroup() %>%
  select(-dep)

Cale_cons <- bind_rows (Cale_cons_nat, Cale_cons_reg, Cale_cons_dep)


# 4.3 Calcul des valeurs des indicateurs calés
# A partir de la table des indicateurs à caler

# On empile toutes les tables de calage
cale <- bind_rows (Cale_cons, Cale_typ_tot)

# Liste des indicateurs à caler

# Indic_a_caler <- str_subset(levels(indic_ecln$Indicateur), c("Encours","Mises"))
Indic_a_caler <- c( str_subset(levels(indic_ecln$Indicateur), "Encours"),  str_subset(levels(indic_ecln$Indicateur), "Mises") )

indic_ecln_ss_com <- indic_ecln_ss_com %>%
  mutate(indic_calage = ifelse(TypeZone %in% c("France", "Régions", "Départements") &
                                 Indicateur %in% Indic_a_caler &
                                 Periode == millesime, "oui", "non"))
                                 # Periode == "2023T2", "oui", "non"))


# extraction dans la table des indicateurs ECLN des indicateurs à caler

Indic_cale <- indic_ecln_ss_com %>%
  filter(indic_calage == "oui") %>%
    mutate ( Calage = case_when(Indicateur == 'Mises en vente - Appartements' |  Indicateur == 'Encours - Appartements' ~ 'Cale - Appartements',
                                Indicateur == 'Mises en vente - Maisons' | Indicateur == 'Encours - Maisons' ~ 'Cale - Maisons',
                                Indicateur == 'Mises en vente - Constructions neuves' | Indicateur == 'Encours - Constructions neuves' ~ 'Cale - Constructions neuves',
                                Indicateur == 'Mises en vente - Constructions sur existant' | Indicateur == 'Encours - Constructions sur existant' ~ 'Cale - Constructions neuves sur existant',
                                Indicateur == 'Mises en vente - Logements' | Indicateur == 'Encours - Logements' ~ 'Cale - Logements'
                              ))


Indic_cale <- Indic_cale %>%
  left_join(cale) %>%
  mutate(Valeur = ifelse(is.na(Cale), Valeur, Valeur + Cale))


# 4.4 Table finale = table des indicateurs à caler + celle des indicateurs non calés

# # On empile la table des indicateurs calés avec la table des indic_non calés


Indic_final <- bind_rows( indic_ecln_ss_com %>%
                          filter(indic_calage == "non") ,
                          Indic_cale %>% select (-Cale, -Calage)) %>%
            select(-indic_calage)


# 5. Calcul des indicateurs annuels glissants
# -----------------------------------------------------------------


 # Attention les encours sont un stock, ils ne sont donc pas sommable sur une année

indicateurs_non_sommables <- str_subset(levels(indic_ecln$Indicateur), "Encours")

# On ajoute une colonne valeur_cumul qui correspond au cumul annuel glissant sauf pour les encours = valeur du trimestre

Indic_final<- Indic_final %>%
  lazy_dt() %>%
  group_by(TypeZone, Zone, CodeZone, Indicateur) %>%
  mutate(Valeur_cumul = Valeur + lag(Valeur) + lag(Valeur, 2) + lag(Valeur, 3)) %>%
  ungroup() %>%
  mutate(Valeur_cumul = ifelse(Indicateur %in% indicateurs_non_sommables, Valeur, Valeur_cumul)) %>%
  as_tibble()


# 5. Calcul des valeurs trimestrielles et cumul annuel
# ----------------------------------------------------
# L'objectif est de calculer :
# - des indicateurs annuels glissants et de différencier les indicateurs trimestriels / annuels
# - des taux d'évolution sur 12 mois pour chauqe indicatzeur
# - d'autres indicateurs
#     PrixM2_Maisons = Prix_Maisons / Surface_Maisons,
#     PrixM2_Appartements = Prix_Appartements / Surface_Appartements,
#     PrixM2_Logements = Prix_Logements / Surface_Logements,
#     PrixPar_Maisons = Prix_Maisons / Ventes_Maisons,
#     PrixPar_Appartements = Prix_Appartements / Ventes_Appartements,
#     PrixPar_Logements

# Dans la table finale, on aura la source, le type de l'indicateur (trimestriel, annuel)

# Appel de la fonction FormatDate
source("R/FormatDate.R")

indic_ecln_trim <- Indic_final %>%
  select(-Valeur_cumul) %>%
  mutate(Indicateur = str_replace_all(Indicateur, " - ", "_")) %>%
  spread(Indicateur, Valeur, fill = 0) %>%
  mutate(
    PrixM2_Maisons = Prix_Maisons / Surface_Maisons,
    PrixM2_Appartements = Prix_Appartements / Surface_Appartements,
    PrixM2_Logements = Prix_Logements / Surface_Logements,
    PrixPar_Maisons = Prix_Maisons / Ventes_Maisons,
    PrixPar_Appartements = Prix_Appartements / Ventes_Appartements,
    PrixPar_Logements = Prix_Logements / Ventes_Logements
  ) %>%
  gather(Indicateur, Valeur, Encours_Appartements:PrixPar_Logements) %>%
  mutate(
    Indicateur = str_replace_all(Indicateur, "_", " - "),
    Periode = FormatDate(Periode, Periodicite = "Trim", sep = "T"),
    Source = "ECLN",
    TypeIndicateur = "Trimestriel"
  )

indic_ecln_cumul <- Indic_final %>%
  select(-Valeur) %>%
  mutate(Indicateur = str_replace_all(Indicateur, " - ", "_")) %>%
  spread(Indicateur, Valeur_cumul, fill = 0) %>%
  mutate(
    PrixM2_Maisons = Prix_Maisons / Surface_Maisons,
    PrixM2_Appartements = Prix_Appartements / Surface_Appartements,
    PrixM2_Logements = Prix_Logements / Surface_Logements,
    PrixPar_Maisons = Prix_Maisons / Ventes_Maisons,
    PrixPar_Appartements = Prix_Appartements / Ventes_Appartements,
    PrixPar_Logements = Prix_Logements / Ventes_Logements
  ) %>%
  gather(Indicateur, Valeur, Encours_Appartements:PrixPar_Logements) %>%
  mutate(
    Indicateur = str_replace_all(Indicateur, "_", " - "),
    Periode = FormatDate(Periode, Periodicite = "Trim", sep = "T"),
    Source = "ECLN",
    TypeIndicateur = "Cumul annuel"
  )
# %>%
#  filter(Periode > "2011-01-01")

# Aggrétation finale -----

TauxEvolution12Mois <- function(.data) {
  .data %>%
    arrange(Source, TypeZone, Zone, CodeZone, TypeIndicateur, Indicateur) %>%
    select(Source, TypeZone, Zone, CodeZone, TypeIndicateur, Indicateur, Periode, Valeur) %>%
    group_by(Source, TypeZone, Zone, CodeZone, TypeIndicateur, Indicateur) %>%
    mutate(TauxEvolution12Mois = round(100 * Valeur / lag(Valeur, 4) - 100, 1)) %>%
    ungroup()
}
indic_ecln_cumul <- TauxEvolution12Mois(indic_ecln_cumul)
indic_ecln_trim <- TauxEvolution12Mois(indic_ecln_trim)

indic_ecln_non_secret <- bind_rows(indic_ecln_cumul, indic_ecln_trim) %>%
  mutate_if(is.character, as.factor) %>%
  mutate(TypeZone = fct_relevel(TypeZone, "France", "Régions", "Départements", "Epci"))

indic_ecln <- indic_ecln_non_secret

usethis::use_data(indic_ecln, overwrite = TRUE)

